==> nextcloud-app-contacts-3.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/lt_LT.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Adresatai",
    "All contacts" : "Visi adresatai",
    "A contacts app for Nextcloud" : "Adresatų programėlė, skirta Nextcloud",
    "Add new property" : "Pridėti naują savybę",
    "Loading" : "Įkeliama",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Šis adresatas yra tik skaitymo veiksenoje. Jūs neturite leidimo taisyti šį adresatą.",
    "Download" : "Atsisiųsti",
    "Delete" : "Ištrinti",
    "Addressbook" : "Adresų knyga",
    "Groups" : "Grupės",
    "New contact" : "Naujas adresatas",
    "Syntax error. Cannot open the contact." : "Sintaksės klaida. Nepavyko atverti adresato.",
    "No errors" : "Klaidų nėra",
    "Open your browser console for more details" : "Išsamesnei informacijai, atverkite savo naršyklės pultą",
    "No results" : "Rezultatų nėra",
    "Copy link" : "Kopijuoti nuorodą",
    "Copied" : "Nukopijuota",
    "Can not copy" : "Nepavyksta nukopijuoti",
    "Rename" : "Pervadinti",
    "Enabled" : "Įjungta",
    "Disabled" : "Išjungta",
    "This will delete the addressbook and every contacts within it" : "Tai ištrins adresų knygą ir visus joje esančius adresatus",
    "Delete {addressbook} ?" : "Ištrinti {addressbook} ?",
    "Deletion of addressbook was not successful." : "Adresų knygos ištrynimas buvo nesėkmingas.",
    "Renaming of addressbook was not successful." : "Adresų knygos pervadinimas buvo nesėkmingas.",
    "Addressbook copied to clipboard" : "Adresų knyga nukopijuota į iškarpinę",
    "Addressbook was not copied to clipboard." : "Adresų knyga nebuvo nukopijuota į iškarpinę.",
    "Unable to change permissions." : "Nepavyko pakeisti leidimų.",
    "Import into" : "Importuoti į",
    "Importing is disabled because there are no address books available" : "Importavimas yra išjungtas, nes nėra prieinamų adresų knygų",
    "Address book name" : "Adresų knygos pavadinimas",
    "An error occurred, unable to create the addressbook." : "Įvyko klaida, nepavyko sukurti adresų knygos.",
    "First name" : "Vardas",
    "Last name" : "Pavardė",
    "Sort by {sorting}" : "Rikiuoti pagal {sorting}",
    "Unable to create the contact." : "Nepavyko sukurti adresato.",
    "Contact not found" : "Adresatas nerastas",
    "Nickname" : "Slapyvardis",
    "Website" : "Svetainė",
    "Federated Cloud ID" : "Federacinės debesijos ID",
    "Home" : "Namų",
    "Address" : "Adresas",
    "Extended address" : "Išplėstinis adresas",
    "City" : "Miestas",
    "Postal code" : "Pašto kodas",
    "Country" : "Šalis",
    "Anniversary" : "Metinės",
    "The date of marriage, or equivalent, of this contact" : "Šio adresato santuokos ar lygiavertė data",
    "Date of death" : "Mirties data",
    "Email" : "El. paštas",
    "Instant messaging" : "Pokalbių programa",
    "Phone" : "Telefonas",
    "Mobile" : "Mobilusis",
    "Work mobile" : "Darbo mobilusis",
    "Home mobile" : "Namų mobilusis",
    "Fax" : "Faksas",
    "Fax home" : "Namų faksas",
    "Fax work" : "Darbo faksas",
    "Pager" : "Pranešimų gaviklis",
    "Car" : "Automobilis",
    "Work pager" : "Darbo pranešimų gaviklis",
    "Social network" : "Socialinis tinklas",
    "The url of the profile. e.g. https://www.facebook.com/Nextclouders/ " : "Profilio URL adresas, pvz., https://www.facebook.com/Nextclouders/ ",
    "Relationship" : "Ryšiai",
    "Spouse" : "Sutuoktinis",
    "Child" : "Vaikas",
    "Mother" : "Mama",
    "Father" : "Tėtis",
    "Parent" : "Tėvai",
    "Brother" : "Brolis",
    "Sister" : "Sesuo",
    "Relative" : "Giminaičiai",
    "Friend" : "Draugas",
    "Colleague" : "Bendradarbiai",
    "Manager" : "Vadovas",
    "Assistant" : "Asistentas",
    "Co-worker" : "Bendradarbis",
    "Gender" : "Lytis",
    "Female" : "Moteris",
    "Male" : "Vyras",
    "None" : "Nėra",
    "Unknown" : "Nežinoma",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["Nepavyko perskaityti {failed} adresato","Nepavyko perskaityti {failed} adresatų","Nepavyko perskaityti {failed} adresatų","Nepavyko perskaityti {failed} adresato"],
    "An error occurred" : "Įvyko klaida"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-app-contacts-3.1.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/lt_LT.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Adresatai",
    "All contacts" : "Visi adresatai",
    "A contacts app for Nextcloud" : "Adresatų programėlė, skirta Nextcloud",
    "Add new property" : "Pridėti naują savybę",
    "Upload a new picture" : "Įkelti naują paveikslėlį",
    "Loading" : "Įkeliama",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Šis adresatas yra tik skaitymo veiksenoje. Jūs neturite leidimo taisyti šį adresatą.",
    "Download" : "Atsisiųsti",
    "Generate QR Code" : "Generuoti QR kodą",
    "Delete" : "Ištrinti",
    "Addressbook" : "Adresų knyga",
    "Groups" : "Grupės",
    "New contact" : "Naujas adresatas",
    "Syntax error. Cannot open the contact." : "Sintaksės klaida. Nepavyko atverti adresato.",
    "No errors" : "Klaidų nėra",
    "Open your browser console for more details" : "Išsamesnei informacijai, atverkite savo naršyklės pultą",
    "No results" : "Rezultatų nėra",
    "Copy link" : "Kopijuoti nuorodą",
    "Copied" : "Nukopijuota",
    "Can not copy" : "Nepavyksta nukopijuoti",
    "Rename" : "Pervadinti",
    "Enabled" : "Įjungta",
    "Disabled" : "Išjungta",
    "This will delete the addressbook and every contacts within it" : "Tai ištrins adresų knygą ir visus joje esančius adresatus",
    "Delete {addressbook} ?" : "Ištrinti {addressbook} ?",
    "Deletion of addressbook was not successful." : "Adresų knygos ištrynimas buvo nesėkmingas.",
    "Renaming of addressbook was not successful." : "Adresų knygos pervadinimas buvo nesėkmingas.",
    "Addressbook copied to clipboard" : "Adresų knyga nukopijuota į iškarpinę",
    "Addressbook was not copied to clipboard." : "Adresų knyga nebuvo nukopijuota į iškarpinę.",
    "Share with users or groups" : "Dalintis su naudotojais ar grupėmis",
    "can edit" : "gali keisti",
    "Unable to change permissions." : "Nepavyko pakeisti leidimų.",
    "Import into" : "Importuoti į",
    "Importing is disabled because there are no address books available" : "Importavimas yra išjungtas, nes nėra prieinamų adresų knygų",
    "Address book name" : "Adresų knygos pavadinimas",
    "An error occurred, unable to create the addressbook." : "Įvyko klaida, nepavyko sukurti adresų knygos.",
    "First name" : "Vardas",
    "Last name" : "Pavardė",
    "Sort by {sorting}" : "Rikiuoti pagal {sorting}",
    "Unable to create the contact." : "Nepavyko sukurti adresato.",
    "Contact not found" : "Adresatas nerastas",
    "Nickname" : "Slapyvardis",
    "Copy to full name" : "Kopijuoti į vardą, pavardę",
    "Website" : "Svetainė",
    "Federated Cloud ID" : "Federacinės debesijos ID",
    "Home" : "Namų",
    "Address" : "Adresas",
    "Extended address" : "Išplėstinis adresas",
    "City" : "Miestas",
    "Postal code" : "Pašto kodas",
    "Country" : "Šalis",
    "Anniversary" : "Metinės",
    "The date of marriage, or equivalent, of this contact" : "Šio adresato santuokos ar lygiavertė data",
    "Date of death" : "Mirties data",
    "Email" : "El. paštas",
    "Instant messaging" : "Pokalbių programa",
    "Phone" : "Telefonas",
    "Mobile" : "Mobilusis",
    "Work mobile" : "Darbo mobilusis",
    "Home mobile" : "Namų mobilusis",
    "Fax" : "Faksas",
    "Fax home" : "Namų faksas",
    "Fax work" : "Darbo faksas",
    "Pager" : "Pranešimų gaviklis",
    "Car" : "Automobilis",
    "Work pager" : "Darbo pranešimų gaviklis",
    "Social network" : "Socialinis tinklas",
    "The url of the profile. e.g. https://www.facebook.com/Nextclouders/ " : "Profilio URL adresas, pvz., https://www.facebook.com/Nextclouders/ ",
    "Relationship" : "Ryšiai",
    "Spouse" : "Sutuoktinis",
    "Child" : "Vaikas",
    "Mother" : "Mama",
    "Father" : "Tėtis",
    "Parent" : "Tėvai",
    "Brother" : "Brolis",
    "Sister" : "Sesuo",
    "Relative" : "Giminaičiai",
    "Friend" : "Draugas",
    "Colleague" : "Bendradarbiai",
    "Manager" : "Vadovas",
    "Assistant" : "Asistentas",
    "Co-worker" : "Bendradarbis",
    "Gender" : "Lytis",
    "Female" : "Moteris",
    "Male" : "Vyras",
    "None" : "Nėra",
    "Unknown" : "Nežinoma",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["Nepavyko perskaityti {failed} adresato","Nepavyko perskaityti {failed} adresatų","Nepavyko perskaityti {failed} adresatų","Nepavyko perskaityti {failed} adresato"],
    "An error occurred" : "Įvyko klaida"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
